const currentUrl = window.location.href;

// close popups with escape key
document.addEventListener("keydown", (event) => {
  if (event.isComposing || event.key === 'Escape') {
    Array.from(document.getElementsByClassName("popup")).forEach(function(x) {
        x.style.display = 'none';
    });
    document.getElementById("registerPopupText").innerText = "";
  }
});

// register popup
document.getElementById("register").addEventListener("click", function () {
    registerPopup.style.display = 'flex';
});
// cancel
document.getElementById("registercancel").addEventListener("click", function () {
    registerPopup.style.display = 'none';
    document.getElementById("registerPopupText").innerText = "";
});
// confirm
document.getElementById("registerconfirm").addEventListener("click", async function () {
    const apiUrl = `${currentUrl}account/register`;
    const inputFieldSharedSecret = document.getElementById("sharedsecret");
    const inputFieldPublicKey = document.getElementById("publickey");
    let pubkey = null;
    if (!inputFieldPublicKey.value) {
        const { privateKey, publicKey } = await genKey();
        pubkey = exportedKeyToPem(publicKey, "public");
        document.getElementById("registerPopupText").innerText = exportedKeyToPem(privateKey, "private");
    } else {
        pubkey = inputFieldPublicKey.value;
    }
    const postData = {
        sharedSecret: inputFieldSharedSecret.value,
        publicKey: pubkey
    };
    // clear input fields
    inputFieldSharedSecret.value='';
    inputFieldPublicKey.value='';

    const requestOptions = {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
        },
        body: JSON.stringify(postData)
    };
    const response = await fetch(apiUrl, requestOptions)
        .catch(error => {
        console.error('Error during POST request:', error);
    });

    if (response.ok) {
        console.log(response);
    } else {
        throw new Error('Error in server response');
    }
});

//login popup
document.getElementById("login").addEventListener("click", function () {
    loginPopup.style.display = 'flex';
});
// cancel
document.getElementById("logincancel").addEventListener("click", function () {
    loginPopup.style.display = 'none';
});
// confirm
document.getElementById("loginconfirm").addEventListener("click", async function () {
    const apiUrl = `${currentUrl}account/login`;
    const inputFieldPrivateKey = document.getElementById("privatekey");
    const response = await fetch(apiUrl, { method: 'GET' });
    if (!response.ok) {
        throw new Error('Failed to fetch challenge');
    }
    const { challenge } = await response.json();
    console.log("Received challenge:", challenge);

    privKey = await pemToKey(inputFieldPrivateKey.value, "private");

    const encoder = new TextEncoder();
    encodedData = encoder.encode(challenge);

    // Sign the data using the private key.
    const signature = await crypto.subtle.sign(
        {
            name: "Ed25519",
        },
        privKey,
        encodedData,
    );
    let signatureString = ab2str(signature);
    let signatureBase64 = window.btoa(signatureString);

    const verifyApiUrl = `${currentUrl}account/verify-challenge`;
    const verifyResponse = await fetch(verifyApiUrl, {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json'
        },
        body: JSON.stringify({
            signature: signatureBase64
        })
    });

    if (!verifyResponse.ok) {
        throw new Error('Failed to verify the challenge');
    }

    const verifyResult = await verifyResponse.json();
    console.log("Verification result:", verifyResult);
});
